Package: tidyverse
Title: Easily Install and Load the 'Tidyverse'
Version: 2.0.0
Authors@R: c(
    person("Hadley", "Wickham", , "hadley@rstudio.com", role = c("aut", "cre")),
    person("RStudio", role = c("cph", "fnd"))
  )
Description: The 'tidyverse' is a set of packages that work in harmony
    because they share common data representations and 'API' design. This
    package is designed to make it easy to install and load multiple
    'tidyverse' packages in a single step. Learn more about the
    'tidyverse' at <https://www.tidyverse.org>.
License: MIT + file LICENSE
URL: https://tidyverse.tidyverse.org,
        https://github.com/tidyverse/tidyverse
BugReports: https://github.com/tidyverse/tidyverse/issues
Depends: R (>= 3.3)
Imports: broom (>= 1.0.3), conflicted (>= 1.2.0), cli (>= 3.6.0),
        dbplyr (>= 2.3.0), dplyr (>= 1.1.0), dtplyr (>= 1.2.2), forcats
        (>= 1.0.0), ggplot2 (>= 3.4.1), googledrive (>= 2.0.0),
        googlesheets4 (>= 1.0.1), haven (>= 2.5.1), hms (>= 1.1.2),
        httr (>= 1.4.4), jsonlite (>= 1.8.4), lubridate (>= 1.9.2),
        magrittr (>= 2.0.3), modelr (>= 0.1.10), pillar (>= 1.8.1),
        purrr (>= 1.0.1), ragg (>= 1.2.5), readr (>= 2.1.4), readxl (>=
        1.4.2), reprex (>= 2.0.2), rlang (>= 1.0.6), rstudioapi (>=
        0.14), rvest (>= 1.0.3), stringr (>= 1.5.0), tibble (>= 3.1.8),
        tidyr (>= 1.3.0), xml2 (>= 1.3.3)
Suggests: covr (>= 3.6.1), feather (>= 0.3.5), glue (>= 1.6.2), mockr
        (>= 0.2.0), knitr (>= 1.41), rmarkdown (>= 2.20), testthat (>=
        3.1.6)
VignetteBuilder: knitr
Config/Needs/website: tidyverse/tidytemplate
Config/testthat/edition: 3
Encoding: UTF-8
RoxygenNote: 7.2.3
NeedsCompilation: no
Packaged: 2023-02-21 13:20:46 UTC; hadleywickham
Author: Hadley Wickham [aut, cre],
  RStudio [cph, fnd]
Maintainer: Hadley Wickham <hadley@rstudio.com>
Repository: CRAN
Date/Publication: 2023-02-22 09:20:06 UTC
Built: R 4.6.0; ; 2026-04-30 18:32:19 UTC; unix
