# Generated by roxygen2: do not edit by hand

S3method(print,tidyverse_conflicts)
S3method(print,tidyverse_logo)
export(tidyverse_conflicts)
export(tidyverse_deps)
export(tidyverse_logo)
export(tidyverse_packages)
export(tidyverse_sitrep)
export(tidyverse_update)
importFrom(magrittr,"%>%")
