% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/conflicts.R
\name{tidyverse_conflicts}
\alias{tidyverse_conflicts}
\title{Conflicts between the tidyverse and other packages}
\usage{
tidyverse_conflicts(only = NULL)
}
\arguments{
\item{only}{Set this to a character vector to restrict to conflicts only
with these packages.}
}
\description{
This function lists all the conflicts between packages in the tidyverse
and other packages that you have loaded.
}
\details{
There are four conflicts that are deliberately ignored: \code{intersect},
\code{union}, \code{setequal}, and \code{setdiff} from dplyr. These functions
make the base equivalents generic, so shouldn't negatively affect any
existing code.
}
\examples{
tidyverse_conflicts()
}
