% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tidyverse.R
\docType{package}
\name{tidyverse-package}
\alias{tidyverse}
\alias{tidyverse-package}
\title{tidyverse: Easily Install and Load the 'Tidyverse'}
\description{
\if{html}{\figure{logo.png}{options: style='float: right' alt='logo' width='120'}}

The 'tidyverse' is a set of packages that work in harmony because they share common data representations and 'API' design. This package is designed to make it easy to install and load multiple 'tidyverse' packages in a single step. Learn more about the 'tidyverse' at \url{https://www.tidyverse.org}.
}
\seealso{
Useful links:
\itemize{
  \item \url{https://tidyverse.tidyverse.org}
  \item \url{https://github.com/tidyverse/tidyverse}
  \item Report bugs at \url{https://github.com/tidyverse/tidyverse/issues}
}

}
\author{
\strong{Maintainer}: Hadley Wickham \email{hadley@rstudio.com}

Other contributors:
\itemize{
  \item RStudio [copyright holder, funder]
}

}
\keyword{internal}
